import getRole from "./getRole.mjs";
export function isElement(node) {
  return node !== null && node.nodeType === node.ELEMENT_NODE;
}
export function isHTMLTableCaptionElement(node) {
  return isElement(node) && node.tagName === "CAPTION";
}
export function isHTMLInputElement(node) {
  return isElement(node) && node.tagName === "INPUT";
}
export function isHTMLSelectElement(node) {
  return isElement(node) && node.tagName === "SELECT";
}
export function isHTMLTableElement(node) {
  return isElement(node) && node.tagName === "TABLE";
}
export function isHTMLTextAreaElement(node) {
  return isElement(node) && node.tagName === "TEXTAREA";
}
export function safeWindow(node) {
  var _ref = node.ownerDocument === null ? node : node.ownerDocument,
      defaultView = _ref.defaultView;

  if (defaultView === null) {
    throw new TypeError("no window available");
  }

  return defaultView;
}
export function isHTMLFieldSetElement(node) {
  return isElement(node) && node.tagName === "FIELDSET";
}
export function isHTMLLegendElement(node) {
  return isElement(node) && node.tagName === "LEGEND";
}
export function isSVGElement(node) {
  return isElement(node) && node.ownerSVGElement !== undefined;
}
export function isSVGSVGElement(node) {
  return isElement(node) && node.tagName === "svg";
}
export function isSVGTitleElement(node) {
  return isSVGElement(node) && node.tagName === "title";
}
/**
 *
 * @param {Node} node -
 * @param {string} attributeName -
 * @returns {Element[]} -
 */

export function queryIdRefs(node, attributeName) {
  if (isElement(node) && node.hasAttribute(attributeName)) {
    // eslint-disable-next-line @typescript-eslint/no-non-null-assertion -- safe due to hasAttribute check
    var ids = node.getAttribute(attributeName).split(" ");
    return ids.map(function (id) {
      return node.ownerDocument.getElementById(id);
    }).filter(function (element) {
      return element !== null;
    } // TODO: why does this not narrow?
    );
  }

  return [];
}
export function hasAnyConcreteRoles(node, roles) {
  if (isElement(node)) {
    return roles.indexOf(getRole(node)) !== -1;
  }

  return false;
}
//# sourceMappingURL=util.mjs.map